import java.awt.Canvas;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.image.BufferedImage;


import com.java4less.vision.RImage;
import com.java4less.vision.pdf417.PDF417Data;
import com.java4less.vision.pdf417.PDF417Reader;



public class PDF417Sample {
	
	
	private String[] testSet={"macropdf.jpg","pdf2_180.jpg","pdf2_270.jpg","pdf2_90.jpg","pdf8.jpg","pdf7.jpg","pdf6.jpg","pdf5.png","pdf4.png","pdf3.jpg","pdf2.jpg","PDF417_1.png" ,"pdf2_corrupt3.jpg","pdf2_corrupt2.jpg","pdf2_corrupt.jpg","pdfbig.jpg","pdf_multiple.png","pdf417scan.jpg"};

	
	private String dir="images\\";
	
	public static void main(String[] args)  {
	
		PDF417Sample sample=new PDF417Sample();
		try {
			

			sample.runTests();
		} catch (Exception e) {

			e.printStackTrace();
		}
		System.exit(0);
		
	}
	
	/**
	 * read all test files
	 *
	 */
	public void runTests() {		
		for (int i=0;i<testSet.length;i++) {
			try {
				
				System.out.println("");
				System.out.println("------------------------------");
				System.out.println("Scanning File: "+testSet[i]);
				System.out.println("");
				scanImage(testSet[i]);
				System.out.println("------------------------------");
			} catch (Exception e) {
				e.printStackTrace();
			}
		}		
	}
	
	/**
	 * scan file
	 * @param file image file

	 * @throws Exception
	 */
	public void scanImage(String file) throws Exception {
		
		Image im=loadImage(dir+file);
		
		PDF417Reader reader=new PDF417Reader();
		
		long prv=System.currentTimeMillis();
		
		RImage rim=new RImage((BufferedImage) im);

        long tim=System.currentTimeMillis();
        PDF417Data[] barcodes=reader.read(rim);
		rim=null;
		im=null;
		
		System.out.print("End. "+(System.currentTimeMillis()-tim)+". ");
		if (barcodes.length==0) System.out.println("*** NO BARCODE FOUND ***");
		
		for (int i=0;i<barcodes.length;i++) {
			
			if (barcodes[i].getConfidence()<0) System.out.println("\bBarcode found but It CONTAINS ERRORS which could not be corrected "+barcodes[i].toString());
			else if (barcodes[i].getConfidence()>0) System.out.println("\nBarcode  found and errors corrected "+barcodes[i].toString());
			else System.out.println("\nBarcode  found "+barcodes[i].toString());
			
			if (barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_SEGMENT)!=null) {
				System.out.println("Macro PDF information:");
				System.out.println("     Segment index: "+barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_SEGMENT));
				System.out.println("     Segment file Id "+barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_FILEID));
				Object o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_SEGMENT_COUNT);
				if (o!=null) System.out.println("     Segment total count: "+o);
				o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_FILENAME);
				if (o!=null) System.out.println("     Filename: "+o);
				o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_FILESIZE);
				if (o!=null) System.out.println("     File size: "+o);
				o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_TIMESTAMP);
				if (o!=null) System.out.println("     TimeStamp: "+o);				
				o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_SENDER);
				if (o!=null) System.out.println("     Sender: "+o);
				o=barcodes[i].getMacroPDFField(PDF417Data.MACROPDF_ADRESSEE);
				if (o!=null) System.out.println("     Adresse: "+o);
				
			}
			
		}
						
	}
	
	/**
	 * load image from file
	 * @param f
	 * @return
	 * @throws Exception
	 */
	public Image loadImage(String f) throws Exception {
			Image im2=null;
			java.awt.MediaTracker mt2=null;

			java.io.FileInputStream in=null;
			byte[] b=null;
			int size=0;


			in=new java.io.FileInputStream( f);
			if (in!=null) {
				size=in.available();
				b=new byte[size];
				in.read(b);
				im2=java.awt.Toolkit.getDefaultToolkit().createImage(b);
				in.close();
			}

			mt2 = new java.awt.MediaTracker(new Canvas());		
			if (im2!=null) {
				if (mt2!=null) {mt2.addImage(im2,0); mt2.waitForID(0);}
				int WidthIm = im2.getWidth(null);
			}


		BufferedImage input=new BufferedImage(im2.getWidth(null),im2.getHeight(null),BufferedImage.TYPE_INT_ARGB);
		
		Graphics g=input.createGraphics();
		g.setColor(Color.white);
		g.fillRect(0,0,im2.getWidth(null),im2.getHeight(null));
		g.drawImage(im2,0,0,null);
		g.dispose();
		g=null;
		
		return input;


		}	

}
